@@ -20,9 +20,9 @@
 import os
 import re
 import sys
+import warnings
 from datetime import datetime
 from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Set, Union
-from urllib.parse import urlparse
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -40,17 +40,30 @@ from airflow.sensors.base import BaseSensorOperator, poke_mode_only
 
 class S3KeySensor(BaseSensorOperator):
     """
-    Waits for a key (a file-like instance on S3) to be present in a S3 bucket.
+    Waits for one or multiple keys (a file-like instance on S3) to be present in a S3 bucket.
     S3 being a key/value it does not support folders. The path is just a key
     a resource.
 
-    :param bucket_key: The key being waited on. Supports full s3:// style url
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:S3KeySensor`
+
+    :param bucket_key: The key(s) being waited on. Supports full s3:// style url
         or relative path from root level. When it's specified as a full s3://
-        url, please leave bucket_name as `None`.
+        url, please leave bucket_name as `None`
     :param bucket_name: Name of the S3 bucket. Only needed when ``bucket_key``
-        is not provided as a full s3:// url.
+        is not provided as a full s3:// url. When specified, all the keys passed to ``bucket_key``
+        refers to this bucket
     :param wildcard_match: whether the bucket_key should be interpreted as a
         Unix wildcard pattern
+    :param check_fn: Function that receives the list of the S3 objects,
+        and returns a boolean:
+        - ``True``: the criteria is met
+        - ``False``: the criteria isn't met
+        **Example**: Wait for any S3 object size more than 1 megabyte  ::
+
+            def check_fn(files: List) -> bool:
+                return any(f.get('Size', 0) > 1048576 for f in files)
     :param aws_conn_id: a reference to the s3 connection
     :param verify: Whether or not to verify SSL certificates for S3 connection.
         By default SSL certificates are verified.
@@ -69,36 +82,55 @@ class S3KeySensor(BaseSensorOperator):
     def __init__(
         self,
         *,
-        bucket_key: str,
+        bucket_key: Union[str, List[str]],
         bucket_name: Optional[str] = None,
         wildcard_match: bool = False,
+        check_fn: Optional[Callable[..., bool]] = None,
         aws_conn_id: str = 'aws_default',
         verify: Optional[Union[str, bool]] = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
         self.bucket_name = bucket_name
-        self.bucket_key = bucket_key
+        self.bucket_key = [bucket_key] if isinstance(bucket_key, str) else bucket_key
         self.wildcard_match = wildcard_match
+        self.check_fn = check_fn
         self.aws_conn_id = aws_conn_id
         self.verify = verify
         self.hook: Optional[S3Hook] = None
 
-    def _resolve_bucket_and_key(self):
-        """If key is URI, parse bucket"""
-        if self.bucket_name is None:
-            self.bucket_name, self.bucket_key = S3Hook.parse_s3_url(self.bucket_key)
+    def _check_key(self, key):
+        bucket_name, key = S3Hook.get_s3_bucket_key(self.bucket_name, key, 'bucket_name', 'bucket_key')
+        self.log.info('Poking for key : s3://%s/%s', bucket_name, key)
+
+        """
+        Set variable `files` which contains a list of dict which contains only the size
+        If needed we might want to add other attributes later
+        Format: [{
+            'Size': int
+        }]
+        """
+        if self.wildcard_match:
+            prefix = re.split(r'[\[\*\?]', key, 1)[0]
+            files = self.get_hook().get_file_metadata(prefix, bucket_name)
+            if len(files) == 0:
+                return False
+
+            # Reduce the set of metadata to size only
+            files = list(map(lambda f: {'Size': f['Size']}, files))
         else:
-            parsed_url = urlparse(self.bucket_key)
-            if parsed_url.scheme != '' or parsed_url.netloc != '':
-                raise AirflowException('If bucket_name provided, bucket_key must be relative path, not URI.')
+            obj = self.get_hook().head_object(key, bucket_name)
+            if obj is None:
+                return False
+            files = [{'Size': obj['ContentLength']}]
+
+        if self.check_fn is not None:
+            return self.check_fn(files)
+
+        return True
 
     def poke(self, context: 'Context'):
-        self._resolve_bucket_and_key()
-        self.log.info('Poking for key : s3://%s/%s', self.bucket_name, self.bucket_key)
-        if self.wildcard_match:
-            return self.get_hook().check_for_wildcard_key(self.bucket_key, self.bucket_name)
-        return self.get_hook().check_for_key(self.bucket_key, self.bucket_name)
+        return all(self._check_key(key) for key in self.bucket_key)
 
     def get_hook(self) -> S3Hook:
         """Create and return an S3Hook"""
@@ -111,37 +143,8 @@ class S3KeySensor(BaseSensorOperator):
 
 class S3KeySizeSensor(S3KeySensor):
     """
-    Waits for a key (a file-like instance on S3) to be present and be more than
-    some size in a S3 bucket.
-    S3 being a key/value it does not support folders. The path is just a key
-    a resource.
-
-    :param bucket_key: The key being waited on. Supports full s3:// style url
-        or relative path from root level. When it's specified as a full s3://
-        url, please leave bucket_name as `None`.
-    :param bucket_name: Name of the S3 bucket. Only needed when ``bucket_key``
-        is not provided as a full s3:// url.
-    :param wildcard_match: whether the bucket_key should be interpreted as a
-        Unix wildcard pattern
-    :param aws_conn_id: a reference to the s3 connection
-    :param verify: Whether or not to verify SSL certificates for S3 connection.
-        By default SSL certificates are verified.
-        You can provide the following values:
-
-        - ``False``: do not validate SSL certificates. SSL will still be used
-                 (unless use_ssl is False), but SSL certificates will not be
-                 verified.
-        - ``path/to/cert/bundle.pem``: A filename of the CA cert bundle to uses.
-                 You can specify this argument if you want to use a different
-                 CA cert bundle than the one used by botocore.
-    :param check_fn: Function that receives the list of the S3 objects,
-        and returns the boolean:
-        - ``True``: a certain criteria is met
-        - ``False``: the criteria isn't met
-        **Example**: Wait for any S3 object size more than 1 megabyte  ::
-
-            def check_fn(self, data: List) -> bool:
-                return any(f.get('Size', 0) > 1048576 for f in data if isinstance(f, dict))
+    This class is deprecated.
+    Please use :class:`~airflow.providers.amazon.aws.sensors.s3.S3KeySensor`.
     """
 
     def __init__(
@@ -150,48 +153,26 @@ class S3KeySizeSensor(S3KeySensor):
         check_fn: Optional[Callable[..., bool]] = None,
         **kwargs,
     ):
-        super().__init__(**kwargs)
-        self.check_fn_user = check_fn
-
-    def poke(self, context: 'Context'):
-        if super().poke(context=context) is False:
-            return False
-
-        s3_objects = self.get_files(s3_hook=self.get_hook())
-        if not s3_objects:
-            return False
-        if self.check_fn_user is not None:
-            return self.check_fn_user(s3_objects)
-        return self.check_fn(s3_objects)
-
-    def get_files(self, s3_hook: S3Hook, delimiter: Optional[str] = '/') -> List:
-        """Gets a list of files in the bucket"""
-        prefix = self.bucket_key
-        config = {
-            'PageSize': None,
-            'MaxItems': None,
-        }
-        if self.wildcard_match:
-            prefix = re.split(r'[\[\*\?]', self.bucket_key, 1)[0]
-
-        paginator = s3_hook.get_conn().get_paginator('list_objects_v2')
-        response = paginator.paginate(
-            Bucket=self.bucket_name, Prefix=prefix, Delimiter=delimiter, PaginationConfig=config
+        warnings.warn(
+            """
+            S3PrefixSensor is deprecated.
+            Please use `airflow.providers.amazon.aws.sensors.s3.S3KeySensor`.
+            """,
+            DeprecationWarning,
+            stacklevel=2,
         )
-        keys: List = []
-        for page in response:
-            if 'Contents' in page:
-                _temp = [k for k in page['Contents'] if isinstance(k.get('Size', None), (int, float))]
-                keys = keys + _temp
-        return keys
 
-    def check_fn(self, data: List, object_min_size: Optional[Union[int, float]] = 0) -> bool:
+        super().__init__(
+            check_fn=check_fn if check_fn is not None else S3KeySizeSensor.default_check_fn, **kwargs
+        )
+
+    @staticmethod
+    def default_check_fn(data: List) -> bool:
         """Default function for checking that S3 Objects have size more than 0
 
         :param data: List of the objects in S3 bucket.
-        :param object_min_size: Checks if the objects sizes are greater then this value.
         """
-        return all(f.get('Size', 0) > object_min_size for f in data if isinstance(f, dict))
+        return all(f.get('Size', 0) > 0 for f in data)
 
 
 @poke_mode_only
@@ -203,6 +184,10 @@ class S3KeysUnchangedSensor(BaseSensorOperator):
     in reschedule mode, as the state of the listed objects in the S3 bucket will
     be lost between rescheduled invocations.
 
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:S3KeysUnchangedSensor`
+
     :param bucket_name: Name of the S3 bucket
     :param prefix: The prefix being waited on. Relative path from bucket root level.
     :param aws_conn_id: a reference to the s3 connection
@@ -332,30 +317,10 @@ class S3KeysUnchangedSensor(BaseSensorOperator):
         return self.is_keys_unchanged(set(self.hook.list_keys(self.bucket_name, prefix=self.prefix)))
 
 
-class S3PrefixSensor(BaseSensorOperator):
+class S3PrefixSensor(S3KeySensor):
     """
-    Waits for a prefix or all prefixes to exist. A prefix is the first part of a key,
-    thus enabling checking of constructs similar to glob ``airfl*`` or
-    SQL LIKE ``'airfl%'``. There is the possibility to precise a delimiter to
-    indicate the hierarchy or keys, meaning that the match will stop at that
-    delimiter. Current code accepts sane delimiters, i.e. characters that
-    are NOT special characters in the Python regex engine.
-
-    :param bucket_name: Name of the S3 bucket
-    :param prefix: The prefix being waited on. Relative path from bucket root level.
-    :param delimiter: The delimiter intended to show hierarchy.
-        Defaults to '/'.
-    :param aws_conn_id: a reference to the s3 connection
-    :param verify: Whether or not to verify SSL certificates for S3 connection.
-        By default SSL certificates are verified.
-        You can provide the following values:
-
-        - ``False``: do not validate SSL certificates. SSL will still be used
-                 (unless use_ssl is False), but SSL certificates will not be
-                 verified.
-        - ``path/to/cert/bundle.pem``: A filename of the CA cert bundle to uses.
-                 You can specify this argument if you want to use a different
-                 CA cert bundle than the one used by botocore.
+    This class is deprecated.
+    Please use :class:`~airflow.providers.amazon.aws.sensors.s3.S3KeySensor`.
     """
 
     template_fields: Sequence[str] = ('prefix', 'bucket_name')
@@ -363,35 +328,21 @@ class S3PrefixSensor(BaseSensorOperator):
     def __init__(
         self,
         *,
-        bucket_name: str,
         prefix: Union[str, List[str]],
         delimiter: str = '/',
-        aws_conn_id: str = 'aws_default',
-        verify: Optional[Union[str, bool]] = None,
         **kwargs,
     ):
-        super().__init__(**kwargs)
-        # Parse
-        self.bucket_name = bucket_name
-        self.prefix = [prefix] if isinstance(prefix, str) else prefix
-        self.delimiter = delimiter
-        self.aws_conn_id = aws_conn_id
-        self.verify = verify
-        self.hook: Optional[S3Hook] = None
-
-    def poke(self, context: 'Context'):
-        self.log.info('Poking for prefix : %s in bucket s3://%s', self.prefix, self.bucket_name)
-        return all(self._check_for_prefix(prefix) for prefix in self.prefix)
-
-    def get_hook(self) -> S3Hook:
-        """Create and return an S3Hook"""
-        if self.hook:
-            return self.hook
-
-        self.hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
-        return self.hook
-
-    def _check_for_prefix(self, prefix: str) -> bool:
-        return self.get_hook().check_for_prefix(
-            prefix=prefix, delimiter=self.delimiter, bucket_name=self.bucket_name
+        warnings.warn(
+            """
+            S3PrefixSensor is deprecated.
+            Please use `airflow.providers.amazon.aws.sensors.s3.S3KeySensor`.
+            """,
+            DeprecationWarning,
+            stacklevel=2,
         )
+
+        self.prefix = prefix
+        prefixes = [self.prefix] if isinstance(self.prefix, str) else self.prefix
+        keys = [pref if pref.endswith(delimiter) else pref + delimiter for pref in prefixes]
+
+        super().__init__(bucket_key=keys, **kwargs)
