@@ -17,50 +17,51 @@
 # under the License.
 """Reads and then deletes the message from SQS queue"""
 import json
+import warnings
 from typing import TYPE_CHECKING, Any, Optional, Sequence
 
 from jsonpath_ng import parse
 from typing_extensions import Literal
 
 from airflow.exceptions import AirflowException
-from airflow.providers.amazon.aws.hooks.sqs import SQSHook
+from airflow.providers.amazon.aws.hooks.sqs import SqsHook
 from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class SQSSensor(BaseSensorOperator):
+class SqsSensor(BaseSensorOperator):
     """
-    Get messages from an SQS queue and then deletes  the message from the SQS queue.
-    If deletion of messages fails an AirflowException is thrown otherwise, the message
-    is pushed through XCom with the key ``messages``.
+    Get messages from an Amazon SQS queue and then delete the messages from the queue.
+    If deletion of messages fails an AirflowException is thrown. Otherwise, the messages
+    are pushed through XCom with the key ``messages``.
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/operator:SqsSensor`
 
     :param aws_conn_id: AWS connection id
-    :type aws_conn_id: str
     :param sqs_queue: The SQS queue url (templated)
-    :type sqs_queue: str
     :param max_messages: The maximum number of messages to retrieve for each poke (templated)
-    :type max_messages: int
     :param wait_time_seconds: The time in seconds to wait for receiving messages (default: 1 second)
-    :type wait_time_seconds: int
     :param visibility_timeout: Visibility timeout, a period of time during which
         Amazon SQS prevents other consumers from receiving and processing the message.
-    :type visibility_timeout: Optional[Int]
     :param message_filtering: Specified how received messages should be filtered. Supported options are:
         `None` (no filtering, default), `'literal'` (message Body literal match) or `'jsonpath'`
         (message Body filtered using a JSONPath expression).
         You may add further methods by overriding the relevant class methods.
-    :type message_filtering: Optional[Literal["literal", "jsonpath"]]
     :param message_filtering_match_values: Optional value/s for the message filter to match on.
         For example, with literal matching, if a message body matches any of the specified values
         then it is included. For JSONPath matching, the result of the JSONPath expression is used
         and may match any of the specified values.
-    :type message_filtering_match_values: Any
     :param message_filtering_config: Additional configuration to pass to the message filter.
         For example with JSONPath filtering you can pass a JSONPath expression string here,
         such as `'foo[*].baz'`. Messages with a Body which does not match are ignored.
-    :type message_filtering_config: Any
+    :param delete_message_on_reception: Default to `True`, the messages are deleted from the queue
+        as soon as being consumed. Otherwise, the messages remain in the queue after consumption and
+        should be deleted manually.
+
     """
 
     template_fields: Sequence[str] = ('sqs_queue', 'max_messages', 'message_filtering_config')
@@ -76,6 +77,7 @@ class SQSSensor(BaseSensorOperator):
         message_filtering: Optional[Literal["literal", "jsonpath"]] = None,
         message_filtering_match_values: Any = None,
         message_filtering_config: Any = None,
+        delete_message_on_reception: bool = True,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -87,6 +89,8 @@ class SQSSensor(BaseSensorOperator):
 
         self.message_filtering = message_filtering
 
+        self.delete_message_on_reception = delete_message_on_reception
+
         if message_filtering_match_values is not None:
             if not isinstance(message_filtering_match_values, set):
                 message_filtering_match_values = set(message_filtering_match_values)
@@ -98,19 +102,18 @@ class SQSSensor(BaseSensorOperator):
 
         self.message_filtering_config = message_filtering_config
 
-        self.hook: Optional[SQSHook] = None
+        self.hook: Optional[SqsHook] = None
 
     def poke(self, context: 'Context'):
         """
         Check for message on subscribed queue and write to xcom the message with key ``messages``
 
         :param context: the context object
-        :type context: dict
         :return: ``True`` if message is available or ``False``
         """
         sqs_conn = self.get_hook().get_conn()
 
-        self.log.info('SQSSensor checking for message on queue: %s', self.sqs_queue)
+        self.log.info('SqsSensor checking for message on queue: %s', self.sqs_queue)
 
         receive_message_kwargs = {
             'QueueUrl': self.sqs_queue,
@@ -129,10 +132,7 @@ class SQSSensor(BaseSensorOperator):
         num_messages = len(messages)
         self.log.info("Received %d messages", num_messages)
 
-        if not num_messages:
-            return False
-
-        if self.message_filtering:
+        if num_messages and self.message_filtering:
             messages = self.filter_messages(messages)
             num_messages = len(messages)
             self.log.info("There are %d messages left after filtering", num_messages)
@@ -140,6 +140,10 @@ class SQSSensor(BaseSensorOperator):
         if not num_messages:
             return False
 
+        if not self.delete_message_on_reception:
+            context['ti'].xcom_push(key='messages', value=messages)
+            return True
+
         self.log.info("Deleting %d messages", num_messages)
 
         entries = [
@@ -155,12 +159,12 @@ class SQSSensor(BaseSensorOperator):
                 'Delete SQS Messages failed ' + str(response) + ' for messages ' + str(messages)
             )
 
-    def get_hook(self) -> SQSHook:
-        """Create and return an SQSHook"""
+    def get_hook(self) -> SqsHook:
+        """Create and return an SqsHook"""
         if self.hook:
             return self.hook
 
-        self.hook = SQSHook(aws_conn_id=self.aws_conn_id)
+        self.hook = SqsHook(aws_conn_id=self.aws_conn_id)
         return self.hook
 
     def filter_messages(self, messages):
@@ -196,3 +200,18 @@ class SQSSensor(BaseSensorOperator):
                     filtered_messages.append(message)
                     break
         return filtered_messages
+
+
+class SQSSensor(SqsSensor):
+    """
+    This sensor is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.sensors.sqs.SqsSensor`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This class is deprecated. Please use `airflow.providers.amazon.aws.sensors.sqs.SqsSensor`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
